@@ -2,16 +2,11 @@ use strict;
 use warnings;
 package YAML::PP::Schema::Core;
 
-our $VERSION = 'v0.39.0'; # VERSION
-
-use YAML::PP::Schema::JSON qw/
-    represent_int represent_float represent_literal represent_bool
-    represent_undef
-/;
+our $VERSION = '0.013'; # VERSION
 
 use B;
 
-use YAML::PP::Common qw/ YAML_PLAIN_SCALAR_STYLE /;
+use YAML::PP::Common qw/ YAML_PLAIN_SCALAR_STYLE YAML_QUOTED_SCALAR_STYLE /;
 
 my $RE_INT_CORE = qr{^([+-]?(?:[0-9]+))$};
 my $RE_FLOAT_CORE = qr{^([+-]?(?:\.[0-9]+|[0-9]+(?:\.[0-9]*)?)(?:[eE][+-]?[0-9]+)?)$};
@@ -56,7 +51,7 @@ sub register {
     $schema->add_resolver(
         tag => 'tag:yaml.org,2002:float',
         match => [ equals => $_ => 0 + "inf" ],
-    ) for (qw/ .inf .Inf .INF +.inf +.Inf +.INF /);
+    ) for (qw/ .inf .Inf .INF /);
     $schema->add_resolver(
         tag => 'tag:yaml.org,2002:float',
         match => [ equals => $_ => 0 - "inf" ],
@@ -70,86 +65,93 @@ sub register {
         match => [ all => sub { $_[1]->{value} } ],
     );
 
+    $schema->add_representer(
+        reftype => "*",
+        code => sub {
+            die "Dumping references not supported yet";
+        },
+    );
+
     my $int_flags = B::SVp_IOK;
     my $float_flags = B::SVp_NOK;
     $schema->add_representer(
         flags => $int_flags,
-        code => \&represent_int,
+        code => sub {
+            my ($rep, $node) = @_;
+            if (int($node->{value}) ne $node->{value}) {
+                return 0;
+            }
+            $node->{style} = YAML_PLAIN_SCALAR_STYLE;
+            $node->{data} = "$node->{value}";
+            return 1;
+        },
     );
+    my %special = ( (0+'nan').'' => '.nan', (0+'inf').'' => '.inf', (0-'inf').'' => '-.inf' );
     $schema->add_representer(
         flags => $float_flags,
-        code => \&represent_float,
+        code => sub {
+            my ($rep, $node) = @_;
+            if (exists $special{ $node->{value} }) {
+                $node->{style} = YAML_PLAIN_SCALAR_STYLE;
+                $node->{data} = $special{ $node->{value} };
+                return 1;
+            }
+            if (0.0 + $node->{value} ne $node->{value}) {
+                return 0;
+            }
+            if (int($node->{value}) eq $node->{value} and not $node->{value} =~ m/\./) {
+                $node->{value} .= '.0';
+            }
+            $node->{style} = YAML_PLAIN_SCALAR_STYLE;
+            $node->{data} = "$node->{value}";
+            return 1;
+        },
     );
     $schema->add_representer(
-        undefined => \&represent_undef,
+        undefined => sub {
+            my ($rep, $node) = @_;
+            $node->{style} = YAML_PLAIN_SCALAR_STYLE;
+            $node->{data} = 'null';
+            return 1;
+        },
     );
     $schema->add_representer(
         equals => $_,
-        code => \&represent_literal,
+        code => sub {
+            my ($rep, $node) = @_;
+            $node->{style} = YAML_QUOTED_SCALAR_STYLE;
+            $node->{data} = "$node->{value}";
+            return 1;
+        },
     ) for ("", qw/
         true TRUE True false FALSE False null NULL Null ~
-        .inf .Inf .INF +.inf +.Inf +.INF -.inf -.Inf -.INF .nan .NaN .NAN
+        .inf .Inf .INF -.inf -.Inf -.INF .nan .NaN .NAN
     /);
     $schema->add_representer(
         regex => qr{$RE_INT_CORE|$RE_FLOAT_CORE|$RE_INT_OCTAL|$RE_INT_HEX},
-        code => \&represent_literal,
+        code => sub {
+            my ($rep, $node) = @_;
+            $node->{style} = YAML_QUOTED_SCALAR_STYLE;
+            $node->{data} = "$node->{value}";
+            return 1;
+        },
     );
 
     if ($schema->bool_class) {
-        for my $class (@{ $schema->bool_class }) {
-            if ($class eq 'perl') {
-                $schema->add_representer(
-                    bool => 1,
-                    code => \&represent_bool,
-                );
-                next;
-            }
-            $schema->add_representer(
-                class_equals => $class,
-                code => \&represent_bool,
-            );
-        }
+        $schema->add_representer(
+            class_equals => $schema->bool_class,
+            code => sub {
+                my ($rep, $node) = @_;
+                my $string = $node->{value} ? 'true' : 'false';
+                $node->{style} = YAML_PLAIN_SCALAR_STYLE;
+                @{ $node->{items} } = $string;
+                $node->{data} = $string;
+                return 1;
+            },
+        );
     }
 
     return;
 }
 
 1;
-
-__END__
-
-=pod
-
-=encoding utf-8
-
-=head1 NAME
-
-YAML::PP::Schema::Core - YAML 1.2 Core Schema
-
-=head1 SYNOPSIS
-
-    my $yp = YAML::PP->new( schema => ['Core'] );
-
-=head1 DESCRIPTION
-
-This schema is the official recommended Core Schema for YAML 1.2.
-It loads additional values to the JSON schema as special types, for
-example C<TRUE> and C<True> additional to C<true>.
-
-Official Schema:
-L<https://yaml.org/spec/1.2/spec.html#id2804923>
-
-Here you can see all Schemas and examples implemented by YAML::PP:
-L<https://perlpunk.github.io/YAML-PP-p5/schemas.html>
-
-=head1 METHODS
-
-=over
-
-=item register
-
-Called by YAML::PP::Schema
-
-=back
-
-=cut
